@@ -5,43 +5,41 @@ use utf8;
 
 BEGIN {
 	$Web::ID::SAN::AUTHORITY = 'cpan:TOBYINK';
-	$Web::ID::SAN::VERSION   = '1.920';
+	$Web::ID::SAN::VERSION   = '1.923';
 }
 
-use Any::Moose 'X::Types::Moose' => [':all'];
-use Web::ID::Types ':all';
+use Web::ID::Types -types;
 use RDF::Query 2.900;
 use URI 0;
 use URI::Escape 0 qw/uri_escape/;
 use Web::ID::RSAKey;
 use Web::ID::Util;
 
-use Any::Moose;
-use namespace::clean -except => 'meta';
+use Moose;
+use namespace::sweep;
 
 has $_ => (
 	is          => read_only,
 	isa         => Str,
 	required    => true,
 	coerce      => false,
-	)
-	for qw(type value);
+) for qw(type value);
 
 has model => (
 	is          => read_only,
 	isa         => Model,
 	lazy_build  => true,
-	);
+);
 
 has key_factory => (
 	is          => read_only,
 	isa         => CodeRef,
 	lazy_build  => true,
-	);
+);
 
 sub _build_model
 {
-	return RDF::Trine::Model->new;
+	return Model->new;
 }
 
 my $default_key_factory = sub
@@ -49,7 +47,7 @@ my $default_key_factory = sub
 	my (%args) = @_;
 	return unless $args{exponent};
 	return unless $args{modulus};
-	Web::ID::RSAKey->new(%args);
+	Rsakey->new(%args);
 };
 
 sub _build_key_factory
@@ -60,7 +58,7 @@ sub _build_key_factory
 sub uri_object
 {
 	my ($self) = @_;
-	return URI->new(sprintf 'urn:x-subject-alt-name:%s:%s', map {uri_escape $_} $self->type, $self->value);
+	return Uri->new(sprintf 'urn:x-subject-alt-name:%s:%s', map {uri_escape $_} $self->type, $self->value);
 }
 
 sub to_string
@@ -89,7 +87,7 @@ Web::ID::SAN - represents a single name from a certificate's subjectAltName fiel
 
 =item C<< new >>
 
-Standard Moose-style constructor. (This class uses L<Any::Moose>.)
+Standard Moose-style constructor. 
 
 =back
 
